NikDetail class

Constructors

NikDetail({required String nik, required Map<String, dynamic> provinsi, required Map<String, dynamic> kabkot, required Map<String, dynamic> kecamatan})

Properties

hashCode int
The hash code for this object.
no setterinherited
kabkot Map<String, dynamic>
final
kecamatan Map<String, dynamic>
final
nik String
final
provinsi Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getKecamatanName() String?
isValid() bool
kabupatenKota() String?
kabupatenKotaId() String
kecamatanId() String
kelamin() String
kodepos() int?
lahir() DateTime
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
province() String?
provinceId() String
toString() String
A string representation of this object.
inherited
uniqcode() String

Operators

operator ==(Object other) bool
The equality operator.
inherited